# Cookbook

This section contains a collection of recipes that demonstrate how to use the Core API features.

## List of recipes

```{toctree}
:maxdepth: 1

azure-openai-with-aad-auth
termination-with-intervention
tool-use-with-intervention
extracting-results-with-an-agent
openai-assistant-agent
langgraph-agent
llamaindex-agent
local-llms-ollama-litellm
instrumenting
topic-subscription-scenarios
structured-output-agent
llm-usage-logger
```
